package org.apidesign.apifest08.currency;


import java.math.BigDecimal;
import java.util.Currency;


/**
 * Convert between two currencies.
 *
 * @author D'Arcy Smith
 * @version 1.0
 */
public interface Convertor
{
    /**
     * Convert an amount from one currency to another.
     * 
     * @param from the currency to convert from.
     * @param to the currency to convert to.
     * @param amount the amount to convert.
     * @return the converted amount.
     * @throws IllegalArgumentException if any of the arguments are null.
     * @throws InvalidConversionException if either from or to are not valid for the convertor.
     */
    BigDecimal convert(Currency   from, 
                       Currency   to, 
                       BigDecimal amount)
        throws InvalidConversionException;
}
