package org.apidesign.apifest08.test;

import junit.framework.TestCase;
import org.apidesign.apifest08.currency.Convertor;
import org.apidesign.apifest08.currency.ConvertorFactory;
import org.apidesign.apifest08.currency.CurrencyType;

/** Finish the Convertor API, and then write bodies of methods inside
 * of this class to match the given tasks. To fullfil your task, use the
 * API define in the <code>org.apidesign.apifest08.currency</code> package.
 * Do not you reflection, or other hacks as your code
 * shall run without any runtime permissions.
 */
public class Task1Test extends TestCase {
    public Task1Test(String testName) {
        super(testName);
    }


    /** Create convertor that understands two currencies, CZK and
     *  USD. Make 1 USD == 17 CZK.
     *
     * Creation of the convertor shall not require subclassing of any class
     * or interface on the client side.
     *
     * @return prepared convertor ready for converting USD to CZK and CZK to USD
     */
    public static Convertor createCZKtoUSD() {
        return ConvertorFactory.getConvertor(CurrencyType.CZK, CurrencyType.USD);
    }

    /** Create convertor that understands two currencies, CZK and
     *  SKK. Make 100 SKK == 80 CZK.
     *
     * Creation of the convertor shall not require subclassing of any class
     * or interface on the client side.
     * 
     * @return prepared convertor ready for converting SKK to CZK and CZK to SKK
     */
    public static Convertor createSKKtoCZK() {
        return ConvertorFactory.getConvertor(CurrencyType.SKK, CurrencyType.CZK);
    }
    
    /** Use the convertor from <code>createCZKtoUSD</code> method and do few conversions
     * with it.
     */
    public void testCurrencyCZKUSD() throws Exception {
        Convertor c = createCZKtoUSD();

        // convert $5 to CZK using c:
        // assertEquals("Result is 85 CZK");
        assertEquals(85, c.convertTo(5));

        // convert $8 to CZK
        // assertEquals("Result is 136 CZK");
        assertEquals(136, c.convertTo(8));

        // convert 1003CZK to USD
        // assertEquals("Result is 59 USD");
        assertEquals(59, c.convertFrom(1003));
    }

    /** Use the convertor from <code>createSKKtoCZK</code> method and do few conversions
     * with it.
     */
    public void testCurrencySKKCZK() throws Exception {
        Convertor c = createSKKtoCZK();
        // convert 16CZK using c:
        // assertEquals("Result is 20 SKK");
        assertEquals(20, c.convertFrom(16));

        // convert 500SKK to CZK
        // assertEquals("Result is 400 CZK");
        assertEquals(400, c.convertTo(500));
    }
}

