
package org.apidesign.apifest08.currency;

import java.math.BigDecimal;

/**
 * Exchange rate value. Contains <code>from</code> and <code>to</code> value.
 * 
 * @author arnostvalicek
 */
public class ExchangeRate {
    private BigDecimal numberFor;
    private BigDecimal numberGet;

    /**
     * Constructor for new exchange rate holding two values - <em>from value</em> and <em>to value</em>
     * @param fromValue Exchange rate <em>from value</em>
     * @param toValue Exchange rate <em>to value</em>
     */
    public  ExchangeRate(BigDecimal fromValue, BigDecimal toValue) {
        this.numberFor = fromValue;
        this.numberGet = toValue;
    }
    
    /**
     * Create new instance of <code>ExchangeRate</code> based on provided exchange rate, but swapping its
     * <em>from</em> and <em>to</em> value.
     * <p>
     * Provided exchange rate is not chaged, this method returns different instance describing reverted exchange rate.
     * 
     * @param rate Exchange rate which describes rate to be reverted.
     * @return Instance of reverted rate.
     */
    public static ExchangeRate createRevertedRate(ExchangeRate rate) {
        ExchangeRate reverted = new ExchangeRate(rate.getToValue(), rate.getFromValue());
        return reverted;
    }

    @Override
    public String toString() {
        return "for "+numberFor+" recieve "+numberGet+" @"+getClass().getName();
    }
    
    /**
     * Return exchange rate <em>from</em> value stored in this object.
     * @return Returns <em>from</em> value for this exchange rate.
     */
    public BigDecimal getFromValue() {
        return numberFor;
    }
    
    /**
     * Return exchange rate <em>to</em> value stored in this object.
     * @return Returns <em>to</em> value for this exchange rate.
     */
    public BigDecimal getToValue() {
        return numberGet;
    }
    
    
//    public ExchangeRate createExchangeRate(BigDecimal forValue, BigDecimal getValue) {
//        ExchangeRate rate = new ExchangeRate(forValue, getValue);
//        return rate;
//    }
    
    
    
}
